function varargout = pezdemo(varargin)
% Main Application M-file for pezdemo.fig
%    FIG = PEZDEMO launch main GUI.
%    PEZDEMO('callback_name', ...) invoke the named callback.

% Last Modified by GUIDE v2.0 25-Oct-2001 22:07:28

% 14-May-2002 - Rajbabu
% o) Added version check, screen size check and fixed minor bug/typo.
% o) Added callback for online 'Help', along with required update in 
%    pezdemo.fig using GUIDE
% 05-Dec-2002 - J McClellan
%       Final release for SP First
%       Fixed warning when deleting poles/zeros when none are present
%  
  
if nargin == 0  % LAUNCH GUI

  %---  Check the installation, the Matlab Version, and the Screen Size  ---%
  errCmd = 'errordlg(lasterr,''Error Initializing Figure''); error(lasterr);';
  %cmdCheck1 = 'installcheck;';
  cmdCheck2 = 'MATLABVER = versioncheck(6.0);';
  cmdCheck3 = 'screensizecheck([800 600]);';
  cmdCheck4 = ['adjustpath(''' mfilename ''');'];
  %eval(cmdCheck1,errCmd);       % Simple installation check
  eval(cmdCheck2,errCmd);       % Check Matlab Version
  eval(cmdCheck3,errCmd);       % Check Screen Size
  eval(cmdCheck4,errCmd);       % Adjust path if necessary
    
  % Set up and invoke the GUI
  fig = openfig(mfilename,'reuse');

	% Generate a structure of handles to pass to callbacks, and store it. 
    handles = guihandles(fig);

    handles = initialize_pez(handles);
    handles.MATLABVER = versioncheck(6.0);
    
    guidata(fig, handles);
    
    
	if nargout > 0
		varargout{1} = fig;
	end

elseif ischar(varargin{1}) % INVOKE NAMED SUBFUNCTION OR CALLBACK

	try
		[varargout{1:nargout}] = feval(varargin{:}); % FEVAL switchyard
	catch
		disp(lasterr);
	end

end


%| ABOUT CALLBACKS:
%| GUIDE automatically appends subfunction prototypes to this file, and 
%| sets objects' callback properties to call them through the FEVAL 
%| switchyard above. This comment describes that mechanism.
%|
%| Each callback subfunction declaration has the following form:
%| <SUBFUNCTION_NAME>(H, EVENTDATA, HANDLES, VARARGIN)
%|
%| The subfunction name is composed using the object's Tag and the 
%| callback type separated by '_', e.g. 'slider2_Callback',
%| 'figure1_CloseRequestFcn', 'axis1_ButtondownFcn'.
%|
%| H is the callback object's handle (obtained using GCBO).
%|
%| EVENTDATA is empty, but reserved for future use.
%|
%| HANDLES is a structure containing handles of components in GUI using
%| tags as fieldnames, e.g. handles.figure1, handles.slider2. This
%| structure is created at GUI startup using GUIHANDLES and stored in
%| the figure's application data using GUIDATA. A copy of the structure
%| is passed to each callback.  You can store additional information in
%| this structure at GUI startup, and you can change the structure
%| during callbacks.  Call guidata(h, handles) after changing your
%| copy to replace the stored original so that subsequent callbacks see
%| the updates. Type "help guihandles" and "help guidata" for more
%| information.
%|
%| VARARGIN contains any extra arguments you have passed to the
%| callback. Specify the extra arguments by editing the callback
%| property in the inspector. By default, GUIDE sets the property to:
%| <MFILENAME>('<SUBFUNCTION_NAME>', gcbo, [], guidata(gcbo))
%| Add any extra arguments after the last argument, before the final
%| closing parenthesis.

function varargout =  menu_import_Callback(h, eventdata, handles, varargin)
%Call for "Import..."
[fname, pname] = uigetfile('*.mat','Import...');
if pname ~= 0
    load ([pname,fname]);
    handles.k = savedata{1};
    handles.poleloc = savedata{2};
    handles.zeroloc = savedata{3};
    
    set(handles.listbox_pole,'String',savedata{4});
    set(handles.listbox_zero,'String',savedata{5});
    set(handles.edit_gain,'String',handles.k);

    pezdemo('menu_LineWidth_Callback',h,[],handles,savedata{6});
    pezdemo('menu_LineColor_Callback',h,[],handles,savedata{7});
    
    handles.connection = savedata{8};
    handles.connecttype = savedata{9};
    
    handles = recal(handles, 'pole_to_poly');
    handles = plot_gph(handles);

    
    guidata(handles.figure_pez, handles);
end
% --------------------------------------------------------------------
function varargout =  menu_export_Callback(h, eventdata, handles, varargin)
%Call for "Export..."
[fname, pname] = uiputfile('*.mat','Export...');
if pname ~= 0
    savedata = {handles.k,...
                handles.poleloc,...
                handles.zeroloc,...
                get(handles.listbox_pole,'String'),...
                get(handles.listbox_zero,'String'),...
                get(handles.linepezzero,'LineWidth'),...
                get(handles.linepezzero,'Color'),...
                handles.connection,...
                handles.connecttype};
    save ([pname,fname], 'savedata');

end
% --------------------------------------------------------------------
function varargout =  menu_print_Callback(h, eventdata, handles, varargin)
%Call for "Print..."
printdlg
% --------------------------------------------------------------------
function varargout =  menu_exit_Callback(h, eventdata, handles, varargin)
%Call for "Exit"
delete(handles.showplot_h.figure_showplot);
delete(handles.config_h.figure_config);
delete(handles.figure_pez);
% --------------------------------------------------------------------





function varargout =  menu_addpole_Callback(h, eventdata, handles, varargin)
%Call for Add pole
set(handles.axes_pzplot,'ButtonDownFcn',[mfilename, '(''getclickpt'', guidata(gcbo), ''addpole'')']);
set(handles.figure_pez,'WindowButtonUpFcn',[mfilename, '(''resetclickpt'', guidata(gcbo))']);
setptr(handles.figure_pez,'crosshair');
% --------------------------------------------------------------------
function varargout =  menu_addzero_Callback(h, eventdata, handles, varargin)
%Call for Add zero
set(handles.axes_pzplot,'ButtonDownFcn',[mfilename, '(''getclickpt'', guidata(gcbo), ''addzero'')']);
set(handles.figure_pez,'WindowButtonUpFcn',[mfilename, '(''resetclickpt'', guidata(gcbo))']);
setptr(handles.figure_pez,'crosshair');
% --------------------------------------------------------------------
function varargout =  menu_addpez_Callback(h, eventdata, handles, varargin)
%Call for Add pole and zero
set(handles.axes_pzplot,'ButtonDownFcn',[mfilename, '(''getclickpt'', guidata(gcbo), ''addpez'')']);
set(handles.figure_pez,'WindowButtonUpFcn',[mfilename, '(''resetclickpt'', guidata(gcbo))']);
setptr(handles.figure_pez,'crosshair');
% --------------------------------------------------------------------
function varargout =  menu_delpole_Callback(h, eventdata, handles, varargin)
%Call for Remove all poles
set(handles.listbox_pole,'String',[],'Value',1);
set([handles.selectedpole, handles.selectedzero],'XData',[],'YData',[]);
handles.poleloc = [];

if( ~isempty(handles.connecttype) )
    polestring = find(handles.connecttype == 'x');
    handles.connection(polestring,:) = [];
    handles.connection(:,polestring) = [];
    handles.connecttype(polestring) = [];
end

handles = recal(handles, 'pole_to_poly');
handles = plot_gph(handles);

guidata(handles.figure_pez, handles);
% --------------------------------------------------------------------
function varargout =  menu_delzero_Callback(h, eventdata, handles, varargin)
%Call for Remove all zeros
set(handles.listbox_zero,'String',[],'Value',1);
set([handles.selectedzero, handles.showplot_h.selectedzero],'XData',[],'YData',[]);
handles.zeroloc = [];

if( ~isempty(handles.connecttype) )
    zerostring = find(handles.connecttype == 'o');
    handles.connection(zerostring,:) = [];
    handles.connection(:,zerostring) = [];
    handles.connecttype(zerostring) = [];
end

handles = recal(handles, 'pole_to_poly');
handles = plot_gph(handles);

guidata(handles.figure_pez, handles);
% --------------------------------------------------------------------
function varargout =  menu_delall_Callback(h, eventdata, handles, varargin)
%Call for Remove all
set([handles.listbox_pole, handles.listbox_zero],'String',[],'Value',1);
set([handles.selectedpole, handles.showplot_h.selectedpole],'XData',[],'YData',[]);
set([handles.selectedzero, handles.showplot_h.selectedzero],'XData',[],'YData',[]);
handles.poleloc = [];
handles.zeroloc = [];

handles.connection = [];
handles.connecttype = [];

handles = recal(handles, 'pole_to_poly');
handles = plot_gph(handles);

guidata(handles.figure_pez, handles);
% --------------------------------------------------------------------


function varargout =  menu_Zoom_Callback(h, eventdata, handles, varargin)
%Call for Zoom
umtoggle(findall(0,'tag','Zoom Enable'));
set(handles.figure_pez,'WindowButtonMotionFcn','');
set(handles.axes_pzplot,'ButtonDownFcn','')
set(handles.figure_pez,'WindowButtonUpFcn','');
set(handles.figure_pez,'Pointer','arrow');

if strcmp(get(h, 'tag'), 'Zoom Enable')
    if get(findall(0,'tag','tb_zoomenable'), 'Value') == 1;
        set(findall(0,'tag','tb_zoomenable'), 'Value', 0);
    else
        set(findall(0,'tag','tb_zoomenable'), 'Value', 1);
    end
end

if  strcmp(get(handles.figure_pez,'HandleVisibility'), 'off')
    set(handles.figure_pez,'HandleVisibility','on');
    axes(handles.axes_pzplot);
    zoom on;
    set(handles.pezpb,'Visible','off');
else
    set(handles.pezpb,'Visible','on');
    axes(handles.axes_pzplot);
    zoom off;
    set(handles.figure_pez,'HandleVisibility','off');
end

pezdemo('resetclickpt', handles);
guidata(handles.figure_pez, handles);

% --------------------------------------------------------------------
function varargout =  menu_ShowGraph_Callback(h, eventdata, handles, varargin)
%Call for ShowGraph
set(handles.showplot_h.figure_showplot,'Visible','on');

set(handles.showplot_h.figure_showplot,'WindowButtonMotionFcn','');
set(handles.showplot_h.axes_pzplot,'ButtonDownFcn',[mfilename, '(''startdrag'',guidata(gcbo),1)']);
set(handles.showplot_h.figure_showplot,'WindowButtonUpFcn',[mfilename, '(''resetclickpt'', guidata(gcbo),1)']);
set(handles.showplot_h.figure_showplot,'Pointer','arrow');
set([handles.selectedpole, handles.showplot_h.selectedpole],'XData',[],'YData',[]);
set([handles.selectedzero, handles.showplot_h.selectedzero],'XData',[],'YData',[]);

set(handles.figure_pez,'WindowButtonMotionFcn','');
set(handles.axes_pzplot,'ButtonDownFcn','')
set(handles.figure_pez,'WindowButtonUpFcn','');
set(handles.figure_pez,'Pointer','arrow');
guidata(handles.showplot_h.figure_showplot, handles);

% --------------------------------------------------------------------
function varargout =  menu_Setting_Callback(h, eventdata, handles, varargin)
%Call for Settings
set(handles.config_h.edit_a,'String',num2str(handles.a));
set(handles.config_h.edit_b,'String',num2str(handles.b));
guidata(handles.config_h.figure_config, handles);
set(handles.config_h.figure_config,'Visible','on');

% --------------------------------------------------------------------
function varargout =  menu_ClickEnable_Callback(h, eventdata, handles, varargin)
%Call for Click Enable
%umtoggle(h);
umtoggle(findall(0,'tag','Click Enable'));

if strcmp(get(h, 'tag'), 'Click Enable')
    if get(findall(0,'tag','tb_clickenable'), 'Value') == 1;
        set(findall(0,'tag','tb_clickenable'), 'Value', 0);
    else
        set(findall(0,'tag','tb_clickenable'), 'Value', 1);
    end
end

pezdemo('resetclickpt', guidata(gcbo));
% --------------------------------------------------------------------
function varargout =  menu_LineWidth_Callback(h, eventdata, handles, varargin)
set([handles.linemag,...
    handles.linephase,...
    handles.lineimp_cir,...
    handles.lineimp_lin,...
    handles.lineimpimg_cir,...
    handles.lineimpimg_lin,...
    handles.linepezzero,...
    handles.linepezpole,...
    handles.selectedpole,...
    handles.selectedzero,...
    handles.showplot_h.linemag,...
    handles.showplot_h.linephase,...
    handles.showplot_h.lineimp_cir,...
    handles.showplot_h.lineimp_lin,...
    handles.showplot_h.linepezzero,...
    handles.showplot_h.linepezpole,...
    handles.showplot_h.selectedpole,...
    handles.showplot_h.selectedzero],'LineWidth',varargin{1});
set(handles.grp_widthtag,'Checked','off');
umtoggle(handles.grp_widthtag(varargin{1}));

% --------------------------------------------------------------------
function varargout =  menu_LineColor_Callback(h, eventdata, handles, varargin)
set([handles.linemag,...
    handles.linephase,...
    handles.lineimp_cir,...
    handles.lineimp_lin,...
    handles.linepezzero,...
    handles.linepezpole,...
    handles.showplot_h.linemag,...
    handles.showplot_h.linephase,...
    handles.showplot_h.lineimp_cir,...
    handles.showplot_h.lineimp_lin,...
    handles.showplot_h.linepezzero,...
    handles.showplot_h.linepezpole],'Color',varargin{1});
set(handles.textcolor,'ForegroundColor',varargin{1});
set([handles.lineimp_cir,...
    handles.showplot_h.lineimp_cir],'MarkerFaceColor',varargin{1});
    
set(handles.grp_colortag,'Checked','off');
temp = [0,1,4,2,6];
umtoggle(handles.grp_colortag(find(temp == bin2dec([num2str(varargin{1}(1)),num2str(varargin{1}(2)),num2str(varargin{1}(3))]))));
% --------------------------------------------------------------------
function varargout = menu_RepeatedAdd_Callback(h, eventdata, handles, varargin)
%umtoggle(h);
umtoggle(findall(0,'tag','Add Repeatedly'));
if strcmp(handles.repeatedadd, 'off')
    handles.repeatedadd = 'on';
else
    handles.repeatedadd = 'off';
end

if strcmp(get(h, 'tag'), 'Add Repeatedly')
    if get(findall(0,'tag','tb_addrepeatedly'), 'Value') == 1;
        set(findall(0,'tag','tb_addrepeatedly'), 'Value', 0);
    else
        set(findall(0,'tag','tb_addrepeatedly'), 'Value', 1);
    end
end

guidata(handles.figure_pez, handles);
% --------------------------------------------------------------------
function varargout = menu_Unlink_Callback(h, eventdata, handles, varargin)

if strcmp(get(findobj(findall(0,'type','figure'),'tag','Click Enable'),'Checked'), 'on')
    tempvalue = handles.tempvalue;
    zero_selected = 0;
    if tempvalue > length(handles.poleloc)
        tempvalue = tempvalue-length(handles.poleloc);
        zero_selected = 1;
    end
    
    sxpole = get(handles.selectedpole,'XData');
    sxzero = get(handles.selectedzero,'XData');
    
    if isempty(sxzero)
        polestring = find(handles.connecttype == 'x');
        polelength = length(handles.connecttype);

        handles.connection(:,polestring(tempvalue)) = zeros(1,polelength);
        handles.connection(polestring(tempvalue),:) = [zeros(1,polestring(tempvalue)-1),1,zeros(1,polelength - polestring(tempvalue))];

        set([handles.selectedpole, handles.showplot_h.selectedpole],...
            'XData',real(handles.poleloc(handles.tempvalue)),...
            'YData',imag(handles.poleloc(handles.tempvalue)));
    
        guidata(handles.figure_pez, handles);
    elseif isempty(sxpole)

        zerostring = find(handles.connecttype == 'o');
        zerolength = length(handles.connecttype);
    
        handles.connection(:,zerostring(tempvalue)) = zeros(1,zerolength);
        handles.connection(zerostring(tempvalue),:) = [zeros(1,zerostring(tempvalue)-1),1,zeros(1,zerolength - zerostring(tempvalue))];

        set([handles.selectedzero, handles.showplot_h.selectedzero],...
            'XData',real(handles.zeroloc(tempvalue)),...
            'YData',imag(handles.zeroloc(tempvalue)));
        guidata(handles.figure_pez, handles);
    else
        if zero_selected
            zerostring = find(handles.connecttype == 'o');
            zerolength = length(handles.connecttype);

            linkzero = setdiff(intersect(find(handles.connection(:,zerostring(tempvalue))),find(handles.connecttype == 'o')),zerostring(tempvalue));
            if ~isempty(linkzero)
                handles.connection(:,linkzero) = zeros(1,zerolength);
                handles.connection(linkzero,:) = [zeros(1,linkzero-1),1,zeros(1,zerolength - linkzero)];
            end
            handles.connection(:,zerostring(tempvalue)) = zeros(1,zerolength);
            handles.connection(zerostring(tempvalue),:) = [zeros(1,zerostring(tempvalue)-1),1,zeros(1,zerolength - zerostring(tempvalue))];

            if ~isempty(linkzero)
                handles.connection(linkzero,zerostring(tempvalue)) = 1;
            end
            
            handles.connection(zerostring(tempvalue),linkzero) = 1;
            set([handles.selectedpole, handles.showplot_h.selectedpole],'XData',[],'YData',[]);
            set([handles.selectedzero, handles.showplot_h.selectedzero],...
                'XData',real(handles.zeroloc([tempvalue,find(zerostring == linkzero(1))])),...
                'YData',imag(handles.zeroloc([tempvalue,find(zerostring == linkzero(1))])));
    
        else
            polestring = find(handles.connecttype == 'x');
            polelength = length(handles.connecttype);
        
            linkpole = setdiff(intersect(find(handles.connection(:,polestring(tempvalue))),find(handles.connecttype == 'x')),polestring(tempvalue));
            if ~isempty(linkpole)
                handles.connection(:,linkpole) = zeros(1,polelength);
                handles.connection(linkpole,:) = [zeros(1,linkpole-1),1,zeros(1,polelength - linkpole)];
                handles.connection(linkpole,polestring(tempvalue)) = 1;
            end
            handles.connection(:,polestring(tempvalue)) = zeros(1,polelength);
            handles.connection(polestring(tempvalue),:) = [zeros(1,polestring(tempvalue)-1),1,zeros(1,polelength - polestring(tempvalue))];
            
            if ~isempty(linkpole)
                handles.connection(linkpole,polestring(tempvalue)) = 1;
            end
            handles.connection(polestring(tempvalue),linkpole) = 1;
        
             set([handles.selectedzero, handles.showplot_h.selectedzero],'XData',[],'YData',[]);
             set([handles.selectedpole, handles.showplot_h.selectedpole],...
                 'XData',real(handles.poleloc([tempvalue,find(polestring == linkpole(1))])),...
                 'YData',imag(handles.poleloc([tempvalue,find(polestring == linkpole(1))])));
         end
    end
    guidata(handles.figure_pez, handles);
end
% --------------------------------------------------------------------





function varargout = edit_gain_Callback(h, eventdata, handles, varargin)
% Stub for Callback of the uicontrol handles.edit1.
% disp('edit1 Callback not implemented yet.')
handles.k = str2num(get(handles.edit_gain,'String'));
handles = recal(handles, 'pole_to_poly');
handles = plot_imp(handles);
%handles = plot_mag(handles);
%handles = plot_phase(handles);
handles = plot_gph(handles);
guidata(handles.figure_pez, handles);
% --------------------------------------------------------------------
function varargout = pb_editpole_Callback(h, eventdata, handles, varargin)
% Stub for Callback of the uicontrol handles.pushbutton1.
if ~isempty(handles.poleloc)
    tempvalue           =   get(handles.listbox_pole,'Value');
    prompt              =   {'Real Part','Imaginary Part'};
    def                 =   {num2str(real(handles.poleloc(tempvalue))),num2str(imag(handles.poleloc(tempvalue)))};
    dlgTitle            =   'Edit Pole';
    lineNo              =   1;
    AddOpts.Resize      =   'off';
    AddOpts.WindowStyle =   'modal';
    AddOpts.Interpreter =   'none';
    answer              =   inputdlg(prompt,dlgTitle,lineNo,def,AddOpts);

    if ~isempty(answer)
        if ~isempty(str2num(answer{1})) & ~isempty(str2num(answer{2}))
            if (str2num(answer{1})^2+str2num(answer{2})^2) ~= 1
                handles.poleloc(tempvalue)= str2num(answer{1})+str2num(answer{2})*i;
                handles = recal(handles, 'pole_to_poly');
                handles = plot_gph(handles);
        
                tempstring = get(handles.listbox_pole,'String');
                tempstring = strvcat(tempstring(1:tempvalue-1,:),... 
                            ['( ',num2str(real(handles.poleloc(tempvalue))),', ',num2str(imag(handles.poleloc(tempvalue))),' )'],...
                            tempstring(tempvalue+1:end,:));
                set(handles.listbox_pole,'String',tempstring);            
    
                polestring = find(handles.connecttype == 'x');
                polelength = length(handles.connecttype);
        
                linkpole = setdiff(intersect(find(handles.connection(:,polestring(tempvalue))),find(handles.connecttype == 'x')),polestring(tempvalue));
                if ~isempty(linkpole)
                    handles.connection(:,linkpole) = zeros(1,polelength);
                    handles.connection(linkpole,:) = [zeros(1,linkpole-1),1,zeros(1,polelength - linkpole)];
                end
                handles.connection(:,polestring(tempvalue)) = zeros(1,polelength);
                handles.connection(polestring(tempvalue),:) = [zeros(1,polestring(tempvalue)-1),1,zeros(1,polelength - polestring(tempvalue))];
                guidata(handles.figure_pez, handles);
            else
                errordlg('Fourier Transform of the Pole Does Not Exist');
            end
        else
            errordlg('Input Must be a Number');    
        end
    end
end


% --------------------------------------------------------------------
function varargout = pb_delpole_Callback(h, eventdata, handles, varargin)
% Stub for Callback of the uicontrol handles.pushbutton2.
% disp('pushbutton2 Callback not implemented yet.')
tempstring = get(handles.listbox_pole,'String');
tempvalue  = get(handles.listbox_pole,'Value');
tempxdata  = get(handles.linepezpole,'XData');
tempydata  = get(handles.linepezpole,'YData');

if ~isempty(handles.poleloc)
    tempstring = strvcat(tempstring(1:tempvalue-1,:),tempstring(tempvalue+1:end,:));
    handles.poleloc = [handles.poleloc(1:tempvalue-1),handles.poleloc(tempvalue+1:end)];

    polestring = find(handles.connecttype == 'x');
    polelength = length(handles.connecttype);
    handles.connecttype(polestring(tempvalue)) = [];
    handles.connection(polestring(tempvalue),:) = [];
    handles.connection(:,polestring(tempvalue)) = [];
end
    
handles = recal(handles, 'pole_to_poly');
handles = plot_gph(handles);

set(handles.listbox_pole,'String',tempstring,'Value',1);
guidata(handles.figure_pez, handles);

% --------------------------------------------------------------------
function varargout = pb_editzero_Callback(h, eventdata, handles, varargin)
% Stub for Callback of the uicontrol handles.pushbutton3.
% disp('pushbutton3 Callback not implemented yet.')
if ~isempty(handles.zeroloc)
    tempvalue           =   get(handles.listbox_zero,'Value');
    prompt              =   {'Real Part','Imaginary Part'};
    def                 =   {num2str(real(handles.zeroloc(tempvalue))),num2str(imag(handles.zeroloc(tempvalue)))};
    dlgTitle            =   'Edit Zero';
    lineNo              =   1;
    AddOpts.Resize      =   'off';
    AddOpts.WindowStyle =   'modal';
    AddOpts.Interpreter =   'none';
    answer              =   inputdlg(prompt,dlgTitle,lineNo,def,AddOpts);
    if ~isempty(answer)
        if ~isempty(str2num(answer{1})) & ~isempty(str2num(answer{2}))
            handles.zeroloc(tempvalue)  = str2num(answer{1})+str2num(answer{2})*i;
            handles = recal(handles, 'pole_to_poly');
            handles = plot_gph(handles);
    
            tempstring = get(handles.listbox_zero,'String');
            tempstring = strvcat(tempstring(1:tempvalue-1,:),... 
                        ['( ',num2str(real(handles.zeroloc(tempvalue))),', ',num2str(imag(handles.zeroloc(tempvalue))),' )'],...
                        tempstring(tempvalue+1:end,:));
            set(handles.listbox_zero,'String',tempstring);            

            zerostring = find(handles.connecttype == 'o');
            zerolength = length(handles.connecttype);

            linkzero = setdiff(intersect(find(handles.connection(:,zerostring(tempvalue))),find(handles.connecttype == 'o')),zerostring(tempvalue));
            if ~isempty(linkzero)
                handles.connection(:,linkzero) = zeros(1,zerolength);
                handles.connection(linkzero,:) = [zeros(1,linkzero-1),1,zeros(1,zerolength - linkzero)];
            end
            handles.connection(:,zerostring(tempvalue)) = zeros(1,zerolength);
            handles.connection(zerostring(tempvalue),:) = [zeros(1,zerostring(tempvalue)-1),1,zeros(1,zerolength - zerostring(tempvalue))];
            guidata(handles.figure_pez, handles);
        else    
            errordlg('Input Must be a Number');    
        end
    end
end


% --------------------------------------------------------------------
function varargout = pb_delzero_Callback(h, eventdata, handles, varargin)
% Stub for Callback of the uicontrol handles.pushbutton4.
tempstring = get(handles.listbox_zero,'String');
tempvalue  = get(handles.listbox_zero,'Value');
tempxdata  = get(handles.linepezzero,'XData');
tempydata  = get(handles.linepezzero,'YData');

if ~isempty(handles.zeroloc)
    tempstring = strvcat(tempstring(1:tempvalue-1,:),tempstring(tempvalue+1:end,:));
    handles.zeroloc = [handles.zeroloc(1:tempvalue-1),handles.zeroloc(tempvalue+1:end)];

    zerostring = find(handles.connecttype == 'o');
    zerolength = length(handles.connecttype);
    handles.connecttype(zerostring(tempvalue)) = [];
    handles.connection(zerostring(tempvalue),:) = [];
    handles.connection(:,zerostring(tempvalue)) = [];
end
    
handles = recal(handles, 'pole_to_poly');
handles = plot_gph(handles);

set(handles.listbox_zero,'String',tempstring,'Value',1);

guidata(handles.figure_pez, handles);


% --------------------------------------------------------------------
function varargout = refresh_Callback(handles)
% Stub for Callback
if (~isempty(str2num(get(handles.config_h.edit_a,'String'))) & ~isempty(str2num(get(handles.config_h.edit_b,'String'))))
    tempa =  roots(str2num(get(handles.config_h.edit_a,'String')));
    if ~isempty(find(abs((real(tempa)).^2 + (imag(tempa)).^2 - 1) < 10^(-3)))
        errordlg('Fourier Transform Does Not Exist');
    else
        handles.a = str2num(get(handles.config_h.edit_a,'String'));
        handles.b = str2num(get(handles.config_h.edit_b,'String'));
        handles.k = handles.b(1)/handles.a(1);
        handles = recal(handles, 'poly_to_pole');

        ptpole = length(handles.poleloc);

        tempa = [];
        tempb = [];
        handles.connection = [];
        handles.connecttype = [];
        for i = 1:ptpole
            tempa = strvcat(tempa, ['( ',num2str(real(handles.poleloc(i))),', ',num2str(imag(handles.poleloc(i))),' )']);
            handles.connection = [handles.connection, zeros(i-1,1); zeros(1,i-1), 1];
            handles.connecttype = [handles.connecttype; 'x'];
        end

        pt = length(handles.zeroloc);
        for i = 1:pt
            tempb = strvcat(tempb, ['( ',num2str(real(handles.zeroloc(i))),', ',num2str(imag(handles.zeroloc(i))),' )']);
            temp = length(handles.connecttype);
            handles.connection = [handles.connection, zeros(ptpole+i-1,1); zeros(1,ptpole+i-1), 1];
            handles.connecttype = [handles.connecttype; 'o'];
        end    

        set(handles.listbox_pole,'String',tempa);
        set(handles.listbox_zero,'String',tempb);

        set(handles.edit_gain,'String',handles.k);

        handles = plot_gph(handles);

        guidata(handles.figure_pez, handles);

        pezdemo('resetclickpt', handles);
    end
else
    errordlg('Must Enter A Number');
end
% --------------------------------------------------------------------
function varargout = getclickpt(handles, varargin)
currentpt = get(handles.axes_pzplot,'CurrentPoint');
x = currentpt(1,1);
y = currentpt(1,2);
clicktype = get(handles.figure_pez,'SelectionType');

temppair = 0;

if strcmp(get(findall(0,'tag','Add with Conjugate'),'Checked'),'on')
    temppair = 1;
end

switch varargin{1}
    case 'addpole'
        if strcmp(clicktype,'normal')
            handles.poleloc = [handles.poleloc, x+y*i];
            set(handles.listbox_pole,'String',strvcat(get(handles.listbox_pole,'String'),...
                ['( ',num2str(x),', ',num2str(y),' )']));
            temp = length(handles.connecttype);
            handles.connection = [handles.connection, zeros(temp,1); zeros(1,temp), 1];
            handles.connecttype = [handles.connecttype; 'x'];

            if temppair
                handles.poleloc = [handles.poleloc, x-y*i];
                set(handles.listbox_pole,'String',strvcat(get(handles.listbox_pole,'String'),...
                    ['( ',num2str(x),', ',num2str(-y),' )']));
                temp = length(handles.connecttype);
                handles.connection = [handles.connection, [zeros(temp-1,1); 1]; zeros(1,temp-1), 1, 1];
                handles.connecttype = [handles.connecttype; 'x'];    
            end

            handles = recal(handles, 'pole_to_poly');
            handles = plot_gph(handles);
           
            handles.changed = 'on';
            guidata(handles.figure_pez, handles);
        end
    case 'addzero'
        if strcmp(clicktype,'normal')
            handles.zeroloc = [handles.zeroloc, x+y*i];
            set(handles.listbox_zero,'String',strvcat(get(handles.listbox_zero,'String'),...
                ['( ',num2str(x),', ',num2str(y),' )']));
            
            temp = length(handles.connecttype);
            handles.connection = [handles.connection, zeros(temp,1); zeros(1,temp), 1];
            handles.connecttype = [handles.connecttype; 'o'];

            if temppair
                handles.zeroloc = [handles.zeroloc, x-y*i];
                set(handles.listbox_zero,'String',strvcat(get(handles.listbox_zero,'String'),...
                    ['( ',num2str(x),', ',num2str(-y),' )']));
                temp = length(handles.connecttype);
                handles.connection = [handles.connection, [zeros(temp-1,1); 1]; zeros(1,temp-1), 1, 1];
                handles.connecttype = [handles.connecttype; 'o'];
            end
            
            handles = recal(handles, 'pole_to_poly');
            handles = plot_gph(handles);

            handles.changed = 'on';
            guidata(handles.figure_pez, handles);
        end
    case 'addpez'
        switch clicktype
            case 'normal'
                tempx = real(1/(x+y*i));
                tempy = imag(1/(x+y*i));
                if temppair
                    
                    set(handles.listbox_pole,'String',...
                        strvcat(get(handles.listbox_pole,'String'),...
                        ['( ',num2str(x),', ',num2str(y),' )'],...
                        ['( ',num2str(x),', ',num2str(-y),' )']));
                    set(handles.listbox_zero,'String',...
                        strvcat(get(handles.listbox_zero,'String'),...
                        ['( ',num2str(tempx),', ',num2str(tempy),' )'],...
                        ['( ',num2str(tempx),', ',num2str(-tempy),' )']));

                    handles.poleloc = [handles.poleloc, x+y*i, x-y*i];
                    handles.zeroloc = [handles.zeroloc, tempx+tempy*i, tempx-tempy*i];
                
                    temp = length(handles.connecttype);
                    handles.connection = [handles.connection, zeros(temp,4);...
                                          zeros(1,temp), 1, 1, 1, 1; zeros(1,temp), 1, 1, 1, 1;...
                                          zeros(1,temp), 1, 1, 1, 1; zeros(1,temp), 1, 1, 1, 1];
                    handles.connecttype = [handles.connecttype; 'o'; 'o'; 'x'; 'x'];
                else
                    set(handles.listbox_pole,'String',...
                        strvcat(get(handles.listbox_pole,'String'),...
                        ['( ',num2str(x),', ',num2str(y),' )']));
                    set(handles.listbox_zero,'String',...
                        strvcat(get(handles.listbox_zero,'String'),...
                        ['( ',num2str(tempx),', ',num2str(-tempy),' )']));
                    
                    handles.poleloc = [handles.poleloc, x+y*i];
                    handles.zeroloc = [handles.zeroloc, tempx-tempy*i];
                
                    temp = length(handles.connecttype);
                    handles.connection = [handles.connection, zeros(temp,2);...
                                          zeros(1,temp), 1, 1; zeros(1,temp), 1, 1];
                    handles.connecttype = [handles.connecttype; 'o'; 'x'];
                end
                handles = recal(handles, 'pole_to_poly');
                handles = plot_gph(handles);
                    
                handles.changed = 'on';
                guidata(handles.figure_pez, handles);
            case 'alt'
                tempx = real(1/(x+y*i));
                tempy = imag(1/(x+y*i));

                if temppair
                    set(handles.listbox_zero,'String',...
                        strvcat(get(handles.listbox_zero,'String'),...
                        ['( ',num2str(x),', ',num2str(y),' )'],...
                        ['( ',num2str(x),', ',num2str(-y),' )']));
                    set(handles.listbox_pole,'String',...
                        strvcat(get(handles.listbox_pole,'String'),...
                        ['( ',num2str(tempx),', ',num2str(tempy),' )'],...
                        ['( ',num2str(tempx),', ',num2str(-tempy),' )']));
    
                    handles.zeroloc = [handles.zeroloc, x+y*i, x-y*i];
                    handles.poleloc = [handles.poleloc, tempx+tempy*i, tempx-tempy*i];
                
                    temp = length(handles.connecttype);
                    handles.connection = [handles.connection, zeros(temp,4); ...
                                          zeros(1,temp), 1, 1, 1, 1; zeros(1,temp), 1, 1, 1, 1;...
                                          zeros(1,temp), 1, 1, 1, 1; zeros(1,temp), 1, 1, 1, 1];
                    handles.connecttype = [handles.connecttype; 'o'; 'o'; 'x'; 'x'];
                else
                    set(handles.listbox_zero,'String',...
                        strvcat(get(handles.listbox_zero,'String'),...
                        ['( ',num2str(x),', ',num2str(y),' )']));
                    set(handles.listbox_pole,'String',...
                        strvcat(get(handles.listbox_pole,'String'),...
                        ['( ',num2str(tempx),', ',num2str(-tempy),' )']));
    
                    handles.zeroloc = [handles.zeroloc, x+y*i];
                    handles.poleloc = [handles.poleloc, tempx-tempy*i];
                
                    temp = length(handles.connecttype);
                    handles.connection = [handles.connection, zeros(temp,2); ...
                                          zeros(1,temp), 1, 1; zeros(1,temp), 1, 1];
                    handles.connecttype = [handles.connecttype; 'o'; 'x'];
                end
                
                handles = recal(handles, 'pole_to_poly');
                handles = plot_gph(handles);

                handles.changed = 'on';
                guidata(handles.figure_pez, handles);
            otherwise
                error('Error in Add Callback');
            end
    otherwise
end
    
% --------------------------------------------------------------------
function varargout = resetclickpt(handles, varargin)
if isempty(varargin)
    if strcmp(handles.repeatedadd,'off')
        if strcmp(get(findobj(gcbo, 'Label', 'Click Enable'),'Checked'), 'on')
            set(handles.axes_pzplot,'ButtonDownFcn',[mfilename,'(''startselected'',guidata(gcbo))']);
            set(handles.figure_pez,'WindowButtonUpFcn',[mfilename, '(''resetclickpt'', guidata(gcbo))']);
            set(handles.figure_pez,'WindowButtonMotionFcn','');
            set(handles.figure_pez,'Pointer','arrow');
        else    
            set(handles.figure_pez,'WindowButtonMotionFcn','');
            set(handles.axes_pzplot,'ButtonDownFcn',[mfilename, '(''startdrag'',guidata(gcbo))'])
            set(handles.figure_pez,'WindowButtonUpFcn',[mfilename, '(''resetclickpt'', guidata(gcbo))']);
            set(handles.figure_pez,'Pointer','arrow');
            set([handles.selectedpole, handles.showplot_h.selectedpole],'XData',[],'YData',[]);
            set([handles.selectedzero, handles.showplot_h.selectedzero],'XData',[],'YData',[]);
        end
    elseif strcmp(handles.changed,'off')
        if strcmp(get(findobj(gcbo, 'Label', 'Click Enable'),'Checked'), 'on')
            set(handles.axes_pzplot,'ButtonDownFcn',[mfilename,'(''startselected'',guidata(gcbo))']);
            set(handles.figure_pez,'WindowButtonUpFcn',[mfilename, '(''resetclickpt'', guidata(gcbo))']);
            set(handles.figure_pez,'WindowButtonMotionFcn','');
            set(handles.figure_pez,'Pointer','arrow');
        else    
            set(handles.figure_pez,'WindowButtonMotionFcn','');
            set(handles.axes_pzplot,'ButtonDownFcn',[mfilename, '(''startdrag'',guidata(gcbo))'])
            set(handles.figure_pez,'WindowButtonUpFcn',[mfilename, '(''resetclickpt'', guidata(gcbo))']);
            set(handles.figure_pez,'Pointer','arrow');        
            set([handles.selectedpole, handles.showplot_h.selectedpole],'XData',[],'YData',[]);
            set([handles.selectedzero, handles.showplot_h.selectedzero],'XData',[],'YData',[]);
        end
    end
else
    set(handles.showplot_h.figure_showplot,'WindowButtonMotionFcn','');
    set(handles.showplot_h.axes_pzplot,'ButtonDownFcn',[mfilename, '(''startdrag'',guidata(gcbo),1)']);
    set(handles.figure_pez,'WindowButtonUpFcn',[mfilename, '(''resetclickpt'', guidata(gcbo),1)']);
    set(handles.showplot_h.figure_showplot,'Pointer','arrow');
 %   guidata(handles.showplot_h.figure_showplot, handles);
end

handles.changed = 'off';
guidata(handles.figure_pez,handles);
% --------------------------------------------------------------------
function varargout = startdrag(handles, varargin)

if isempty(varargin)
    currentpt = get(handles.axes_pzplot,'CurrentPoint');
    currentfig = handles.figure_pez;
else
    currentpt = get(handles.showplot_h.axes_pzplot,'CurrentPoint');
    currentfig = handles.showplot_h.figure_showplot;
end

clicktype = get(handles.figure_pez,'SelectionType');
if strcmp(clicktype,'normal')
    x = currentpt(1,1);
    y = currentpt(1,2);
    tol = 0.05;


    tempvalue = find( abs(real([handles.poleloc(1:length(handles.poleloc)),handles.zeroloc(1:length(handles.zeroloc))]) - x) <= tol ...
                    & abs(imag([handles.poleloc(1:length(handles.poleloc)),handles.zeroloc(1:length(handles.zeroloc))]) - y) <= tol);

    if ~isempty(tempvalue)
        if tempvalue(1) > length(handles.poleloc)
            handles.tempvalue = tempvalue(1)-length(handles.poleloc);
            zerostring = find(handles.connecttype == 'o');
            polestring = find(handles.connecttype == 'x');
            
            
            tempconnect = find(handles.connection(zerostring(handles.tempvalue),:));
            tempzero = setdiff(intersect(zerostring,tempconnect),zerostring(handles.tempvalue));
            handles.outparm.zeroconnect = [];
            if ~isempty(tempzero)
                handles.outparm.zeroconnect = find(zerostring == sort(setdiff(intersect(zerostring,tempconnect),zerostring(handles.tempvalue))));
            end
            
            temppole = sort(intersect(polestring,tempconnect));
            poleconnect = [];
            if ~isempty(temppole)
                for i = 1:length(temppole)
                    poleconnect = [poleconnect, find(polestring == temppole(i))];
                 end
            else
                poleconnect = [];
            end
            
            if isempty(poleconnect)
                if isempty(varargin)
                    set(currentfig,'WindowButtonMotionFcn',[mfilename, '(''movepez'', guidata(gcbo), ''zero'')']);
                else
                    set(currentfig,'WindowButtonMotionFcn',[mfilename, '(''movepez'', guidata(gcbo), ''zero'',1)']);
                end
            else
                tol = 0.01;
                handles.outparm.poleconnect = poleconnect;
                if abs(imag(1/handles.zeroloc(handles.tempvalue)) - imag(handles.poleloc(handles.outparm.poleconnect(1)))) < tol
                    handles.outparm.type = 1;
                else
                    handles.outparm.type = 0;
                end
                
                if isempty(varargin)
                    set(currentfig,'WindowButtonMotionFcn',[mfilename, '(''movepez'', guidata(gcbo), ''z_pez'')']);
                else
                    set(currentfig,'WindowButtonMotionFcn',[mfilename, '(''movepez'', guidata(gcbo), ''z_pez'',1)']);
                end
            end
        else
            handles.tempvalue = tempvalue(1);
            zerostring = find(handles.connecttype == 'o');
            polestring = find(handles.connecttype == 'x');
 
            tempconnect = find(handles.connection(polestring(handles.tempvalue),:));
            
            temppole = setdiff(intersect(polestring,tempconnect),polestring(handles.tempvalue));
            handles.outparm.poleconnect = [];
            if ~isempty(temppole)
                handles.outparm.poleconnect = find(polestring == sort(setdiff(intersect(polestring,tempconnect),polestring(handles.tempvalue))));
            end
            
            tempzero = sort(intersect(zerostring,tempconnect));
            zeroconnect = [];
            if ~isempty(tempzero)
                for i = 1:length(tempzero)
                    zeroconnect = [zeroconnect, find(zerostring == tempzero(i))];
                 end
            else
                zeroconnect = [];
            end

            if isempty(zeroconnect)
                
                if isempty(varargin)
                    set(currentfig,'WindowButtonMotionFcn',[mfilename, '(''movepez'', guidata(gcbo), ''pole'')']);
                else
                    set(currentfig,'WindowButtonMotionFcn',[mfilename, '(''movepez'', guidata(gcbo), ''pole'',1)']);                
                end
                
            else
                tol = 0.01;
                handles.outparm.zeroconnect = zeroconnect;
                if abs(imag(1/handles.poleloc(handles.tempvalue)) - imag(handles.zeroloc(handles.outparm.zeroconnect(1)))) < tol
                    handles.outparm.type = 1;
                else
                    handles.outparm.type = 0;
                end
                
                if isempty(varargin)
                    set(currentfig,'WindowButtonMotionFcn',[mfilename, '(''movepez'', guidata(gcbo), ''p_pez'')']);
                else
                    set(currentfig,'WindowButtonMotionFcn',[mfilename, '(''movepez'', guidata(gcbo), ''p_pez'',1)']);
                end
                
            end
        end
        guidata(currentfig, handles);
    end
end
   


% --------------------------------------------------------------------
function varargout = movepez(handles, varargin)

if length(varargin) == 1
    currentfig = handles.figure_pez;
    currentplot = handles.axes_pzplot;
else
    currentfig = handles.showplot_h.figure_showplot;
    currentplot = handles.showplot_h.axes_pzplot;
end

setptr(currentfig,'closedhand');
switch varargin{1}
    case 'pole'
        currentpt = get(currentplot,'CurrentPoint');
        
        x = currentpt(1,1);
        y = currentpt(1,2);

        if (x^2+y^2) ~= 1
            x = x + 10^-6;
            y = y + 10^-6;
        end
                    
        tempvalue = handles.tempvalue;
        handles.poleloc(tempvalue) = x+y*i;       
        
        tempstring = get(handles.listbox_pole,'String');
        tempstring = strvcat(tempstring(1:tempvalue-1,:),...
                    ['( ',num2str(x),', ',num2str(y),' )'],...
                    tempstring(tempvalue+1:end,:));
                
        set([handles.selectedpole, handles.showplot_h.selectedpole],'XData',x,'YData',y);
        set([handles.selectedzero, handles.showplot_h.selectedzero],'XData',[],'YData',[]);
        
        if ~isempty(handles.outparm.poleconnect)
            p1 = handles.outparm.poleconnect(1);
            handles.poleloc(p1) = x-y*i;        
            tempstring = strvcat(tempstring(1:p1-1,:),... 
                        ['( ',num2str(x),', ',num2str(-y),' )'],...
                        tempstring(p1+1:size(tempstring,1),:));
            set([handles.selectedpole, handles.showplot_h.selectedpole],'XData',[x,x],'YData',[y,-y]);
        end
        set(handles.listbox_pole,'String',tempstring);          
      
        
        handles = recal(handles, 'pole_to_poly');
        handles = plot_gph(handles);
        
        guidata(currentfig, handles);
        drawnow;

    case 'zero'
        currentpt = get(currentplot,'CurrentPoint');
        x = currentpt(1,1);
        y = currentpt(1,2);
        
        tempvalue = handles.tempvalue;
        handles.zeroloc(tempvalue) = x+y*i;
        
        tempstring = get(handles.listbox_zero,'String');
        tempstring = strvcat(tempstring(1:tempvalue-1,:),... 
                    ['( ',num2str(x),', ',num2str(y),' )'],...
                    tempstring(tempvalue+1:size(tempstring,1),:));

         set([handles.selectedzero, handles.showplot_h.selectedzero],'XData',x,'YData',y);
         set([handles.selectedpole, handles.showplot_h.selectedpole],'XData',[],'YData',[]);
                
        if ~isempty(handles.outparm.zeroconnect)
            z1 = handles.outparm.zeroconnect(1);
            handles.zeroloc(z1) = x-y*i;
            tempstring = strvcat(tempstring(1:z1-1,:),... 
                        ['( ',num2str(x),', ',num2str(-y),' )'],...
                        tempstring(z1+1:size(tempstring,1),:));
            set([handles.selectedzero, handles.showplot_h.selectedzero],'XData',[x,x],'YData',[y,-y]);
        end
        
        set(handles.listbox_zero,'String',tempstring);
        
        handles = recal(handles, 'pole_to_poly');
        handles = plot_gph(handles);
           
        guidata(currentfig, handles);
        drawnow;
    case 'z_pez'
        currentpt = get(currentplot,'CurrentPoint');
        x = currentpt(1,1);
        y = currentpt(1,2);
        
        if (x^2+y^2) ~= 1
            x = x + 10^-6;
            y = y + 10^-6;
        end
        
        tempx = real(1/(x+y*i));
        tempy = imag(1/(x+y*i));

        tempvalue = handles.tempvalue;
        handles.zeroloc(tempvalue) = x+y*i;
        
        tempstring = get(handles.listbox_zero,'String');
        tempstring = strvcat(tempstring(1:tempvalue-1,:),... 
                    ['( ',num2str(x),', ',num2str(y),' )'],...
                    tempstring(tempvalue+1:size(tempstring,1),:));

        set([handles.selectedzero, handles.showplot_h.selectedzero],'XData',x,'YData',y);
                
        if ~isempty(handles.outparm.zeroconnect)
            z1 = handles.outparm.zeroconnect(1);
            handles.zeroloc(z1) = x-y*i;
            tempstring = strvcat(tempstring(1:z1-1,:),... 
                        ['( ',num2str(x),', ',num2str(y),' )'],...
                        tempstring(z1+1:size(tempstring,1),:));
            set([handles.selectedzero, handles.showplot_h.selectedzero],'XData',[x,x],'YData',[y,-y]);
        end
        set(handles.listbox_zero,'String',tempstring);            
        
        tempstring = get(handles.listbox_pole,'String');
        if (handles.outparm.type == 1)
            p1 = handles.outparm.poleconnect(1);
            handles.poleloc(p1) = tempx+tempy*i;
            tempstring = strvcat(tempstring(1:p1-1,:),... 
                        ['( ',num2str(tempx),', ',num2str(tempy),' )'],...
                        tempstring(p1+1:size(tempstring,1),:));
            
            set([handles.selectedpole, handles.showplot_h.selectedpole],'XData',tempx,'YData',tempy);
            
            if length(handles.outparm.poleconnect)>1
                p2 = handles.outparm.poleconnect(2);
                handles.poleloc(p2) = tempx-tempy*i;
                tempstring = strvcat(tempstring(1:p2-1,:),... 
                            ['( ',num2str(tempx),', ',num2str(-tempy),' )'],...
                            tempstring(p2+1:size(tempstring,1),:));
                set([handles.selectedpole, handles.showplot_h.selectedpole],'XData',[tempx,tempx],'YData',[tempy,-tempy]);
            end
        else
            p1 = handles.outparm.poleconnect(1);
            handles.poleloc(p1) = tempx-tempy*i;
            tempstring = strvcat(tempstring(1:p1-1,:),... 
                        ['( ',num2str(tempx),', ',num2str(-tempy),' )'],...
                        tempstring(p1+1:size(tempstring,1),:));

            set([handles.selectedpole, handles.showplot_h.selectedpole],'XData',tempx,'YData',-tempy);
            
            if length(handles.outparm.poleconnect)>1
                p2 = handles.outparm.poleconnect(2);
                handles.poleloc(p2) = tempx+tempy*i;
                tempstring = strvcat(tempstring(1:p2-1,:),... 
                            ['( ',num2str(tempx),', ',num2str(tempy),' )'],...
                            tempstring(p2+1:size(tempstring,1),:));
                
                set([handles.selectedpole, handles.showplot_h.selectedpole],'XData',[tempx,tempx],'YData',[tempy,-tempy]);
            end
        end
        set(handles.listbox_pole,'String',tempstring);   
        
        handles = recal(handles, 'pole_to_poly');
        handles = plot_gph(handles);
        
        guidata(currentfig, handles);
        drawnow;
    case 'p_pez'
        currentpt = get(currentplot,'CurrentPoint');
        x = currentpt(1,1);
        y = currentpt(1,2);
        
        if (x^2+y^2) ~= 1
            x = x + 10^-6;
            y = y + 10^-6;
        end
        
        tempx = real(1/(x+y*i));
        tempy = imag(1/(x+y*i));

        tempvalue = handles.tempvalue;
        handles.poleloc(tempvalue) = x+y*i;
        
        tempstring = get(handles.listbox_pole,'String');
        tempstring = strvcat(tempstring(1:tempvalue-1,:),... 
                    ['( ',num2str(x),', ',num2str(y),' )'],...
                    tempstring(tempvalue+1:size(tempstring,1),:));

        set([handles.selectedpole, handles.showplot_h.selectedpole],'XData',x,'YData',y);
            
        if ~isempty(handles.outparm.poleconnect)
            p1 = handles.outparm.poleconnect(1);
            handles.poleloc(p1) = x-y*i;
            tempstring = strvcat(tempstring(1:p1-1,:),... 
                        ['( ',num2str(x),', ',num2str(-y),' )'],...
                        tempstring(p1+1:size(tempstring,1),:));
            set([handles.selectedpole, handles.showplot_h.selectedpole],'XData',[x,x],'YData',[y,-y]);
        end
        set(handles.listbox_pole,'String',tempstring);            
        
        
        tempstring = get(handles.listbox_zero,'String');
        if (handles.outparm.type == 1)
            z1 = handles.outparm.zeroconnect(1);
            handles.zeroloc(z1) = tempx+tempy*i;
            tempstring = strvcat(tempstring(1:z1-1,:),... 
                        ['( ',num2str(tempx),', ',num2str(tempy),' )'],...
                        tempstring(z1+1:size(tempstring,1),:));
            
            set([handles.selectedzero, handles.showplot_h.selectedzero],'XData',tempx,'YData',tempy);
                    
            if length(handles.outparm.zeroconnect)>1
                z2 = handles.outparm.zeroconnect(2);
                handles.zeroloc(z2) = tempx-tempy*i;
                tempstring = strvcat(tempstring(1:z2-1,:),... 
                            ['( ',num2str(tempx),', ',num2str(-tempy),' )'],...
                            tempstring(z2+1:size(tempstring,1),:));
                set([handles.selectedzero, handles.showplot_h.selectedzero],'XData',[tempx,tempx],'YData',[tempy,-tempy]);
            end
        else
            z1 = handles.outparm.zeroconnect(1);
            handles.zeroloc(z1) = tempx-tempy*i;
            tempstring = strvcat(tempstring(1:z1-1,:),... 
                ['( ',num2str(tempx),', ',num2str(-tempy),' )'],...
                tempstring(z1+1:size(tempstring,1),:));

            set([handles.selectedzero, handles.showplot_h.selectedzero],'XData',tempx,'YData',-tempy);
            
            if length(handles.outparm.zeroconnect)>1
                z2 = handles.outparm.zeroconnect(2);
                handles.zeroloc(z2) = tempx+tempy*i;
                tempstring = strvcat(tempstring(1:z2-1,:),... 
                            ['( ',num2str(tempx),', ',num2str(tempy),' )'],...
                            tempstring(z2+1:size(tempstring,1),:));

                set([handles.selectedzero, handles.showplot_h.selectedzero],'XData',[tempx,tempx],'YData',[tempy,-tempy]);
            end
        end

        set(handles.listbox_zero,'String',tempstring);   
        
        handles = recal(handles, 'pole_to_poly');
        handles = plot_gph(handles);
               
        guidata(currentfig, handles);
        drawnow;
    otherwise
        error('Error in Movepez Callback');
end
% --------------------------------------------------------------------
function varargout = startselected(handles, varargin)
currentpt = get(handles.axes_pzplot,'CurrentPoint');
clicktype = get(handles.figure_pez,'SelectionType');
if strcmp(clicktype,'normal')
    x = currentpt(1,1);
    y = currentpt(1,2);
    tol = 0.05;

    tempvalue = find( abs(real([handles.poleloc(1:length(handles.poleloc)),handles.zeroloc(1:length(handles.zeroloc))]) - x) <= tol ...
                    & abs(imag([handles.poleloc(1:length(handles.poleloc)),handles.zeroloc(1:length(handles.zeroloc))]) - y) <= tol);
    
    if ~isempty(tempvalue)
        if tempvalue(1) > length(handles.poleloc)
            handles.tempvalue = tempvalue(1)-length(handles.poleloc);
            zerostring = find(handles.connecttype == 'o');
            polestring = find(handles.connecttype == 'x');
            
            
            tempconnect = find(handles.connection(zerostring(handles.tempvalue),:));
            tempzero = setdiff(intersect(zerostring,tempconnect),zerostring(handles.tempvalue));
            zeroconnect = [];
            if ~isempty(tempzero)
                zeroconnect = find(zerostring == sort(setdiff(intersect(zerostring,tempconnect),zerostring(handles.tempvalue))));
            end
            
            temppole = sort(intersect(polestring,tempconnect));
            poleconnect = [];
            if ~isempty(temppole)
                for i = 1:length(temppole)
                    poleconnect = [poleconnect, find(polestring == temppole(i))];
                 end
            else
                poleconnect = [];
            end
            
            set([handles.selectedpole, handles.showplot_h.selectedpole],...
                'XData',real(handles.poleloc(poleconnect)),...
                'YData',imag(handles.poleloc(poleconnect)));
            set([handles.selectedzero, handles.showplot_h.selectedzero],...
                'XData',real(handles.zeroloc([handles.tempvalue, zeroconnect])),...
                'YData',imag(handles.zeroloc([handles.tempvalue, zeroconnect])));
            handles.tempvalue = tempvalue(1);
        else
            handles.tempvalue = tempvalue;
            zerostring = find(handles.connecttype == 'o');
            polestring = find(handles.connecttype == 'x');
 
            tempconnect = find(handles.connection(polestring(tempvalue),:));
            
            temppole = setdiff(intersect(polestring,tempconnect),polestring(tempvalue));
            poleconnect = [];
            if ~isempty(temppole)
                poleconnect = find(polestring == sort(setdiff(intersect(polestring,tempconnect),polestring(tempvalue))));
            end
            
            tempzero = sort(intersect(zerostring,tempconnect));
            zeroconnect = [];
            if ~isempty(tempzero)
                for i = 1:length(tempzero)
                    zeroconnect = [zeroconnect, find(zerostring == tempzero(i))];
                 end
            else
                zeroconnect = [];
            end

            set([handles.selectedpole, handles.showplot_h.selectedpole],...
                'XData',real(handles.poleloc([tempvalue, poleconnect])),...
                'YData',imag(handles.poleloc([tempvalue, poleconnect])));
            set([handles.selectedzero, handles.showplot_h.selectedzero],...
                'XData',real(handles.zeroloc(zeroconnect)),...
                'YData',imag(handles.zeroloc(zeroconnect)));    
        end
        guidata(handles.figure_pez, handles);
    end
end
            
% --------------------------------------------------------------------
function varargout = cbgrid_Callback(h, eventdata, handles, varargin)
% Stub for Callback of the uicontrol handles.checkbox1.
if get(h,'Value') == 1
    set([handles.axes_mag, handles.axes_phase, handles.showplot_h.axes_mag, handles.showplot_h.axes_phase], 'XGrid','on','YGrid','on');
else
    set([handles.axes_mag, handles.axes_phase, handles.showplot_h.axes_mag, handles.showplot_h.axes_phase], 'XGrid','off','YGrid','off');
end


% --------------------------------------------------------------------
function varargout = menu_AddConjugate_Callback(h, eventdata, handles, varargin)
umtoggle(findall(0,'tag','Add with Conjugate'));
if strcmp(get(h, 'tag'), 'Add with Conjugate')
    if get(findall(0,'tag','tb_addconjugate'), 'Value') == 1;
        set(findall(0,'tag','tb_addconjugate'), 'Value', 0);
    else
        set(findall(0,'tag','tb_addconjugate'), 'Value', 1);
    end
end


% --------------------------------------------------------------------
function varargout = menu_Help_Callback()
  MATLABVER = versioncheck(6);
  hBar = waitbar(0.25,'Opening internet browser...');
  DefPath = which(mfilename);
  DefPath = ['file:///' strrep(DefPath,filesep,'/') ];
  URL = [ DefPath(1:end-9) , 'help/','index.html'];
  if MATLABVER >= 6
       STAT = web(URL,'-browser');
  else
    STAT = web(URL);
  end
  waitbar(1);
  close(hBar);
  switch STAT
   case {1,2}
    s = {'Either your internet browser could not be launched or' , ...
	 'it was unable to load the help page.  Please use your' , ...
	 'browser to read the file:' , ...
	 ' ', '     index.html', ' ', ...
	 'which is located in the pezdemo help directory.'};
    errordlg(s,'Error launching browser.');
  end
  
 % ------------------------------------------------------------------


